/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Outrun demo.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QGuiApplication>
#include <QQmlApplicationEngine>
#include <QQmlContext>
#include <QtQuick3D/qquick3d.h>
#include <QtGui/QFontDatabase>
#include "receiver.h"

// Android, running on 2 separate displays (QC SA8155P)
// adb root
// adb shell am start --display 0 org.qtproject.outrundemo/org.qtproject.qt.android.bindings.QtActivity
// adb shell am start --display 1 org.qtproject.outrunivi/org.qtproject.qt.android.bindings.QtActivity
// ..or..
// adb shell am start --display 1 org.qtproject.outrunhvac/org.qtproject.qt.android.bindings.QtActivity

int main(int argc, char *argv[])
{
//    qputenv("QT_VULKAN_LIB", "/system/lib/libvulkan.so");
//    qputenv("QSG_RHI_BACKEND", "vulkan");
    if (qEnvironmentVariableIsEmpty("QTGLESSTREAM_DISPLAY")) {
        qputenv("QT_QPA_EGLFS_PHYSICAL_WIDTH", QByteArray("213"));
        qputenv("QT_QPA_EGLFS_PHYSICAL_HEIGHT", QByteArray("120"));

#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
        QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif
    }

    QGuiApplication app(argc, argv);

    QSurfaceFormat::setDefaultFormat(QQuick3D::idealSurfaceFormat(8));

    QQmlApplicationEngine engine;
    QFontDatabase::addApplicationFont(":/fonts/Exo2-Bold.ttf");
    QFontDatabase::addApplicationFont(":/fonts/Exo2-ExtraBold.ttf");
    QFontDatabase::addApplicationFont(":/fonts/Exo2-Medium.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-Bold.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-BoldItalic.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-ExtraBold.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-ExtraBoldItalic.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-Italic.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-Light.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-LightItalic.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-Medium.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-MediumItalic.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-Regular.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-SemiBold.ttf");
    QFontDatabase::addApplicationFont(":/fonts/OpenSans-SemiBoldItalic.ttf");
#ifdef Q_OS_ANDROID
    engine.rootContext()->setContextProperty("android", true);
#else
    engine.rootContext()->setContextProperty("android", false);
#endif
    qmlRegisterType<Receiver>("RemoteControl", 1, 0, "Receiver");
    engine.addImportPath("qrc:/imports");
    engine.addImportPath("qrc:/asset_imports");
    const QUrl url(QStringLiteral("qrc:/main.qml"));
    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
                     &app, [url](QObject *obj, const QUrl &objUrl) {
        if (!obj && url == objUrl)
            QCoreApplication::exit(-1);
    }, Qt::QueuedConnection);
    engine.load(url);

    return app.exec();
}
